<?php

namespace JReviewsDeploy;

function htmxRequest()
{
    return isset($_SERVER['HTTP_HX_REQUEST']) && sanitize_text_field($_SERVER['HTTP_HX_REQUEST']) == 'true';
}

function jr_config($name) 
{
    global $wpdb;

    $query = $wpdb->prepare(
        "SELECT value FROM " . $wpdb->prefix . "jreviews_config WHERE id = %s",
        $name
    );
    
    $result = $wpdb->get_var($query);
    
    return $result;
}

function jr_license()
{
    global $wpdb;

    $tableName = $wpdb->prefix . 'jreviews_license';

    if (! $wpdb->get_var("SHOW TABLES LIKE '$tableName'") === $tableName) {
        return false;
    }

    $query = $wpdb->prepare(
        "SELECT value FROM " . $tableName . " WHERE id = %s",
        'license'
    );
    
    $result = $wpdb->get_var($query);
    
    return $result;
}

function plugin_version($name)
{
    $plugin_file = "$name/$name.php";

    if (! file_exists(WP_PLUGIN_DIR . '/' . $plugin_file)) {
        return null;
    }

    $plugin_data = get_plugin_data(WP_PLUGIN_DIR . '/' . $plugin_file);
    
    $plugin_version = $plugin_data['Version'];
    
    return $plugin_version;
}

function jr_addons()
{
    global $wpdb;

    $query = "SELECT title, name, manifest FROM {$wpdb->prefix}jreviews_addons ORDER BY title";
    $addons = $wpdb->get_results($query);
    
    if (!$addons) {
        return [];
    }
    
    foreach ($addons as &$addon) {
        $manifest = json_decode($addon->manifest);
        $addon->version = $manifest->version;
    }
    
    $last = [
        'paymentcoinbase',
        'paymentmollie',
        'paymentstripe',
    ];

    usort($addons, function ($a, $b) use ($last) {
        if (in_array($a->name, $last) && !in_array($b->name, $last)) {
            return 1;
        } elseif (!in_array($a->name, $last) && in_array($b->name, $last)) {
            return -1;
        }
        return 0;
    });  
        
    return $addons;
}

function jr_addons_array()
{
    $result = [];

    foreach (jr_addons() as $addon) {
        $result[$addon->name] = $addon->version;
    }

    return $result;
}
