<?php defined('ABSPATH') or die;?>

<form id="jreviewsdeploy" 
    hx-select="#jreviewsdeploy"
    hx-target="this"
    hx-swap="outerHTML"
    hx-post="<?= $this->endpoint('startUpdate'); ?>"
    <?php if (! $this->errors() && JReviewsDeploy\htmxRequest() && $this->thereAreProductsWithAvailableUpdates()): ?>
    hx-trigger="load"
    <?php endif;?>
>
    <input type="hidden" name="disabled_addons" value='<?= json_encode($this->disabledAddons()); ?>' />

    <div class="jrdeploy-list-item">
        <h2>Backup! better safe than sorry</h2>
        <p>Have a backup and know how to restore in case of errors. It's strongly encouraged to first test the upgrade on a development site.</p>
    </div>

    <div class="jrdeploy-list-item">
        <h2>Setup, data, media</h2>
        <p>Your JReviews setup, listing data and media files are safe and won't be lost when using JReviews Deploy.</p>
    </div>

    <div class="jrdeploy-list-item" style="margin-bottom: 2.5rem;">
        <h2>File customizations</h2>
        <p>All JReviews and addon core files are removed before installing the updates. If you've made customizations, they should be in overrides to avoid losing them. Using overrides for customizations is not a guarantee of future compatibility. You are responsible for keeping them up to date to ensure there are no compatibility issues with the latest versions.</p>
    </div>

    <div style="margin-bottom: 2rem; display: flex; gap: 2rem; align-items: center;">

        <?php if ($this->thereAreProductsWithAvailableUpdates()): ?>

                <button
                    type="submit"
                    class="btn btn-success"
                    hx-confirm="Continue only if you have a fresh backup and are ready to restore it if necessary?"
                    hx-post="<?= $this->endpoint('startUpdate'); ?>"
                    hx-disabled-elt="this"
                    hx-indicator="#jreviewsdeploy"
                    <?= (JReviewsDeploy\htmxRequest()) ? 'disabled' : ''; ?>
                >Start Update</button>

                <div class="htmx-indicator text-muted">
                    <span class="jrdeploy-pulse" style="font-size: 1rem; margin-right: 1rem;">Updating ...</span>
                </div>

        <?php else: ?>

            <?php
            if (JReviewsDeploy\htmxRequest()):
                $link = site_url('/wp-admin/admin.php?page=jreviews&url=install&sql=1');
            else: 
                $link = site_url('/wp-admin/admin.php?page=jreviews');
            endif;
            ?>

            <a
                class="btn btn-success"
                style="text-decoration: none; font-size: 1rem;"
                href="<?= $link; ?>"
            >You are all caught up! Go to JReviews</a>

        <?php endif; ?>

    </div>

    <?php if ($errors = $this->errors()): ?>

        <div class="mb-5">
            <div style="margin-bottom: 1.5rem; color: #b91c1c; font-size: 1rem;">Update aborted due to errors.</div>

            <?php foreach ($errors as $error): ?>
            <ul style="margin-bottom: 1.5rem; color: #b91c1c; font-size: 1rem;">
                <li><?= $error; ?></li>
            </ul>
            <?php endforeach; ?>

        </div>

    <?php endif; ?>
    
    <table class="widefat striped">
        <tr>
            <th>Product</th>
            <th>Current Version</th>
            <th>New Version</th>
        </tr>
        <?php foreach ($this->products() as $product): ?>
            <tr>
                <td><?= $product['title']; ?></td>
                <td><?= $product['current'] ?? 'Not installed'; ?></td>
                <td class="jrdeploy-version">
                    <?= $product['new'] ?? '<span style="color: #457d54;"><strong>Using latest</strong></span>'; ?>
                    <?php if ($product['new']): ?>
                        <img class="htmx-indicator" src="<?= $this->loadingUrl(); ?>" width="25" style="margin-left: 1rem;" />
                    <?php endif; ?>
                </td>
            </tr>
        <?php endforeach; ?>
    </table>            

</form>